# yolo-pyutils
yolo-pyutils provides utility functions for IO, data-processing, scheduling, common structures etc.

# Installation
```shell
pip install yolo-pyutils
```

Requirements:
* Python 3.6 or higher